@@ -1,12 +1,16 @@
 import os
 
 import pytest
+from sqlalchemy.ext.asyncio import AsyncSession
+
+from tests.mixer import AsyncMixer
 
 os.environ.setdefault('SETTINGS_MODULE', 'tests.conf')  # noqa
 
 from fastapi_toolkit.db import (
     BaseModel,
     create_engine,
+    create_session,
 )
 from tests.models import *  # noqa
 
@@ -24,3 +28,14 @@ async def db():
         await connection.run_sync(BaseModel.metadata.drop_all)
 
     await engine.dispose()
+
+
+@pytest.fixture
+async def session(db) -> AsyncSession:
+    async with create_session() as session:
+        yield session
+
+
+@pytest.fixture
+async def mixer(session) -> AsyncMixer:
+    yield AsyncMixer(session)
